@@ -25,10 +25,8 @@ import (
 	"github.com/Azure/go-autorest/autorest/azure"
 	machinev1 "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
 	apierrors "github.com/openshift/machine-api-operator/pkg/controller/machine"
-	"github.com/pkg/errors"
 	apicorev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/equality"
-	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/klog"
@@ -64,11 +62,6 @@ type MachineScopeParams struct {
 // NewMachineScope creates a new MachineScope from the supplied parameters.
 // This is meant to be called for each machine actuator operation.
 func NewMachineScope(params MachineScopeParams) (*MachineScope, error) {
-	scope, err := NewScope(ScopeParams{AzureClients: params.AzureClients})
-	if err != nil {
-		return nil, err
-	}
-
 	machineConfig, err := MachineConfigFromProviderSpec(params.Machine.Spec.ProviderSpec)
 	if err != nil {
 		return nil, apierrors.InvalidMachineConfiguration(err.Error(), "failed to get machine config")
@@ -76,31 +69,13 @@ func NewMachineScope(params MachineScopeParams) (*MachineScope, error) {
 
 	machineStatus, err := v1beta1.MachineStatusFromProviderStatus(params.Machine.Status.ProviderStatus)
 	if err != nil {
-		return nil, errors.Wrap(err, "failed to get machine provider status")
+		return nil, fmt.Errorf("failed to get machine provider status: %w", err)
 	}
 
-	if machineConfig.CredentialsSecret != nil {
-		if err = updateScope(params.CoreClient, machineConfig.CredentialsSecret, scope); err != nil {
-			return nil, errors.Wrap(err, "failed to update cluster")
-		}
-	}
+	machineScope := &MachineScope{
+		Context:      context.Background(),
+		AzureClients: params.AzureClients,
 
-	scope.ClusterConfig.NetworkResourceGroup = scope.ClusterConfig.ResourceGroup
-
-	if machineConfig.ResourceGroup != "" {
-		scope.ClusterConfig.ResourceGroup = machineConfig.ResourceGroup
-	}
-
-	if machineConfig.NetworkResourceGroup != "" {
-		scope.ClusterConfig.NetworkResourceGroup = machineConfig.NetworkResourceGroup
-	}
-
-	if machineConfig.Location != "" {
-		scope.ClusterConfig.Location = machineConfig.Location
-	}
-
-	return &MachineScope{
-		Scope: scope,
 		// Deep copy the machine since it's change outside of the machine scope
 		// by consumers of the machine scope (e.g. reconciler).
 		Machine:       params.Machine.DeepCopy(),
@@ -112,12 +87,19 @@ func NewMachineScope(params MachineScopeParams) (*MachineScope, error) {
 		origMachine:        params.Machine.DeepCopy(),
 		origMachineStatus:  machineStatus.DeepCopy(),
 		machineToBePatched: controllerclient.MergeFrom(params.Machine.DeepCopy()),
-	}, nil
+	}
+
+	if err = updateFromSecret(params.CoreClient, machineScope); err != nil {
+		return nil, fmt.Errorf("failed to update cluster: %w", err)
+	}
+
+	return machineScope, nil
 }
 
 // MachineScope defines a scope defined around a machine and its cluster.
 type MachineScope struct {
-	*Scope
+	context.Context
+	AzureClients
 
 	Machine       *machinev1.Machine
 	CoreClient    controllerclient.Client
@@ -151,18 +133,7 @@ func (m *MachineScope) Role() string {
 
 // Location returns the machine location.
 func (m *MachineScope) Location() string {
-	return m.Scope.Location()
-}
-
-func (m *MachineScope) setMachineSpec() error {
-	ext, err := v1beta1.EncodeMachineSpec(m.MachineConfig)
-	if err != nil {
-		return err
-	}
-
-	m.Machine.Spec.ProviderSpec.Value = ext
-
-	return nil
+	return m.MachineConfig.Location
 }
 
 func (m *MachineScope) setMachineStatus() error {
@@ -178,10 +149,6 @@ func (m *MachineScope) setMachineStatus() error {
 	}
 
 	m.Machine.Status.ProviderStatus = ext
-
-	time := metav1.Now()
-	m.Machine.Status.LastUpdated = &time
-
 	return err
 }
 
@@ -259,12 +226,15 @@ func unmarshalProviderSpec(spec *runtime.RawExtension) (*v1beta1.AzureMachinePro
 	return &config, nil
 }
 
-func updateScope(coreClient controllerclient.Client, credentialsSecret *apicorev1.SecretReference, scope *Scope) error {
-	if credentialsSecret == nil {
-		return errors.New("provided empty credentials secret")
+func updateFromSecret(coreClient controllerclient.Client, scope *MachineScope) error {
+	if scope.MachineConfig.CredentialsSecret == nil {
+		return nil
 	}
 
-	secretType := types.NamespacedName{Namespace: credentialsSecret.Namespace, Name: credentialsSecret.Name}
+	secretType := types.NamespacedName{
+		Namespace: scope.MachineConfig.CredentialsSecret.Namespace,
+		Name:      scope.MachineConfig.CredentialsSecret.Name,
+	}
 	var secret apicorev1.Secret
 	if err := coreClient.Get(
 		context.Background(),
@@ -275,37 +245,37 @@ func updateScope(coreClient controllerclient.Client, credentialsSecret *apicorev
 
 	subscriptionID, ok := secret.Data[AzureCredsSubscriptionIDKey]
 	if !ok {
-		return errors.Errorf("Azure subscription id %v did not contain key %v",
+		return fmt.Errorf("Azure subscription id %v did not contain key %v",
 			secretType.String(), AzureCredsSubscriptionIDKey)
 	}
 	clientID, ok := secret.Data[AzureCredsClientIDKey]
 	if !ok {
-		return errors.Errorf("Azure client id %v did not contain key %v",
+		return fmt.Errorf("Azure client id %v did not contain key %v",
 			secretType.String(), AzureCredsClientIDKey)
 	}
 	clientSecret, ok := secret.Data[AzureCredsClientSecretKey]
 	if !ok {
-		return errors.Errorf("Azure client secret %v did not contain key %v",
+		return fmt.Errorf("Azure client secret %v did not contain key %v",
 			secretType.String(), AzureCredsClientSecretKey)
 	}
 	tenantID, ok := secret.Data[AzureCredsTenantIDKey]
 	if !ok {
-		return errors.Errorf("Azure tenant id %v did not contain key %v",
+		return fmt.Errorf("Azure tenant id %v did not contain key %v",
 			secretType.String(), AzureCredsTenantIDKey)
 	}
 	resourceGroup, ok := secret.Data[AzureCredsResourceGroupKey]
 	if !ok {
-		return errors.Errorf("Azure resource group %v did not contain key %v",
+		return fmt.Errorf("Azure resource group %v did not contain key %v",
 			secretType.String(), AzureCredsResourceGroupKey)
 	}
 	region, ok := secret.Data[AzureCredsRegionKey]
 	if !ok {
-		return errors.Errorf("Azure region %v did not contain key %v",
+		return fmt.Errorf("Azure region %v did not contain key %v",
 			secretType.String(), AzureCredsRegionKey)
 	}
 	clusterName, ok := secret.Data[AzureResourcePrefix]
 	if !ok {
-		return errors.Errorf("Azure resource prefix %v did not contain key %v",
+		return fmt.Errorf("Azure resource prefix %v did not contain key %v",
 			secretType.String(), AzureResourcePrefix)
 	}
 
@@ -327,14 +297,24 @@ func updateScope(coreClient controllerclient.Client, credentialsSecret *apicorev
 
 	authorizer, err := autorest.NewBearerAuthorizer(token), nil
 	if err != nil {
-		return errors.Errorf("failed to create azure session: %v", err)
+		return fmt.Errorf("failed to create azure session: %v", err)
 	}
 
-	scope.ClusterConfig.ObjectMeta.Name = string(clusterName)
+	if scope.MachineConfig.ResourceGroup == "" {
+		scope.MachineConfig.ResourceGroup = string(resourceGroup)
+	}
+
+	if scope.MachineConfig.NetworkResourceGroup == "" {
+		scope.MachineConfig.NetworkResourceGroup = string(resourceGroup)
+	}
+
+	if scope.MachineConfig.Location == "" {
+		scope.MachineConfig.Location = string(region)
+	}
+
+	scope.MachineConfig.ObjectMeta.Name = string(clusterName)
 	scope.Authorizer = authorizer
 	scope.SubscriptionID = string(subscriptionID)
-	scope.ClusterConfig.ResourceGroup = string(resourceGroup)
-	scope.ClusterConfig.Location = string(region)
 
 	return nil
 }
